@@ -83,6 +83,15 @@ setGeneric("genericExpGetPrecision",
 	return(standardGeneric("genericExpGetPrecision"))
 })
 
+setGeneric("genericGetExpected",
+	function(.Object, model, what, defvar.row) {
+	return(standardGeneric("genericGetExpected"))
+})
+
+setGeneric("genericGetExpectedVector",
+	function(.Object, model, defvar.row) {
+	return(standardGeneric("genericGetExpectedVector"))
+})
 
 setMethod("genericExpAddEntities", "MxBaseExpectation",
 	function(.Object, job, flatJob, labelsData) {
@@ -129,6 +138,12 @@ setMethod("genericExpGetPrecision", "MxBaseExpectation",
 		return(list(stepSize=0.0001, iterations=4L))
 })
 
+setMethod("genericGetExpected", "MxBaseExpectation",
+	function(.Object, model, what, defvar.row) stop("Not implemented"))
+
+setMethod("genericGetExpectedVector", "MxBaseExpectation",
+	function(.Object, model, defvar.row) stop("Not implemented"))
+
 setMethod("$", "MxBaseExpectation", imxExtractSlot)
 
 setReplaceMethod("$", "MxBaseExpectation",
