@@ -28,7 +28,6 @@ mxRun <- function(model, ..., intervals=NULL, silent = FALSE,
 			deparse(width.cutoff = 400L, sys.call())), call. = FALSE)
 	}
 
-	if(!silent) message("Running ", model@name)
 	frontendStart <- Sys.time()
 	garbageArguments <- list(...)
 	if (length(garbageArguments) > 0) {
@@ -213,7 +212,10 @@ runHelper <- function(model, frontendStart,
 	
 	frontendStop <- Sys.time()
 	frontendElapsed <- (frontendStop - frontendStart) - indepElapsed
+	if(!silent) message("Running ", model@name, " with ", numParam, " parameter",
+			    ifelse(numParam==1, "", "s"))
 	if (onlyFrontend) return(model)
+
 	output <- .Call(backend,
 			constraints, matrices, parameters,
 			algebras, expectations, computes,
@@ -238,15 +240,20 @@ runHelper <- function(model, frontendStart,
 	model@output <- nameOptimizerOutput(suppressWarnings, flatModel,
 		names(matrices), names(algebras),
 		names(parameters), output)
-	if(length(model$data) > 0 && model$data$type=="acov"){
+	
+	theFitUnits <- model$output$fitUnits
+	if( length(theFitUnits) > 0 && theFitUnits %in% "r'Wr" ){
 		wlsSEs <- imxWlsStandardErrors(model)
 		model@output$standardErrors <- wlsSEs$SE
-		model@output$hessian <- wlsSEs$Cov
-		model@output$calculatedHessian <- wlsSEs$Cov
+		model@output$hessian <- 2*solve(wlsSEs$Cov) #puts in same units as m2ll Hessian
 		wlsChi <- imxWlsChiSquare(model, J=wlsSEs$Jac)
 		model@output$chi <- wlsChi$Chi
 		model@output$chiDoF <- wlsChi$ChiDoF
 	}
+	if (model@output$status$code < 5 && !is.null(model@output[['infoDefinite']]) &&
+	    !is.na(model@output[['infoDefinite']]) && !model@output[['infoDefinite']]) {
+		model@output$status$code <- 5
+	}
 
 	# Currently runstate preserves the pre-backend state of the model.
 	# Eventually this needs to capture the post-backend state,
@@ -298,10 +305,14 @@ updateModelExpectationDims <- function(model, expectations){
 mxTryHard<-function (model, extraTries = 10, greenOK = FALSE, loc = 1, 
     scale = 0.25,  initialGradientStepSize = .00001, initialGradientIterations = 1,
     initialTolerance=1e-12, checkHess = TRUE, fit2beat = Inf, paste = TRUE,
-    iterationSummary=FALSE, bestInitsOutput=TRUE, showInits=FALSE, verbose=0,
-    ...){
+    iterationSummary=FALSE, bestInitsOutput=TRUE, showInits=FALSE, verbose=0, intervals = FALSE){
+    
+    defaultComputePlan <- (is.null(model@compute) || is(model@compute, 'MxComputeDefault'))
+    
     lastNoError<-TRUE
     
+    generalTolerance<- 1e-5 #used for hessian check and lowest min check
+    
     gradientStepSize<- initialGradientStepSize
     tolerance <- initialTolerance
     lastBestFitCount<-0 #number of consecutive improvements in fit
@@ -313,199 +324,246 @@ mxTryHard<-function (model, extraTries = 10, greenOK = FALSE, loc = 1,
     
     
     while (!stopflag) {
-      
-      if(iterationSummary==TRUE) message(paste0('\nBegin fit attempt ', numdone+1, ' of at maximum ', extraTries +1, ' tries'))
-      
-      if(lastNoError==TRUE) params <- omxGetParameters(model)
-      
-      if(lastBestFitCount == 0 & numdone > 0){ #if the last fit was not the best
-        message('\n Setting gradientStepSize and gradientIterations to defaults')
-        if(exists('bestfit')) params<-bestfit.params #if bestfit exists use this instead
-        if(numdone %% 4 == 0) params<-inits #sometimes, use initial start values instead
-        #       if(numdone %% 5 == 0) { #sometimes, switch optimizers
-        #         if(mxOption(NULL, "Default optimizer")=='CSOLNP') newoptimizer<-'NPSOL'
-        #         if(mxOption(NULL, "Default optimizer")=='NPSOL') newoptimizer<-'CSOLNP'
-        #         message(paste0('Switching to ',newoptimizer,' optimizer for OpenMx temporarily')) 
-        #         mxOption(NULL, "Default optimizer", newoptimizer)
-        #       }
         
-        model <- omxSetParameters(model, labels = names(params), 
-          values = params * runif(length(params),loc-(rnorm(1,scale,1)),loc+(rnorm(1,scale,1))))
+        # if(iterationSummary==TRUE) 
+        message(paste0('\nBegin fit attempt ', numdone+1, ' of at maximum ', extraTries +1, ' tries'))
         
-        gradientStepSize <- initialGradientStepSize
-        #             tolerance <- initialTolerance
-        gradientIterations<-initialGradientIterations
-      }
-      
-      
-      
-      
-      if(lastBestFitCount > 0){ #if the last fit was the best so far
-        if(exists('bestfit')) {
-          params<-bestfit.params      
-          model<-bestfit
-        }
-        message('\n Lowest minimum so far')
+        if(lastNoError==TRUE) params <- omxGetParameters(model)
         
-        
-        if(lastBestFitCount == 3) gradientStepSize <- gradientStepSize *.1
-        if(lastBestFitCount == 4) gradientStepSize <- gradientStepSize *10
-        if(lastBestFitCount  %in% seq(1,100,4)) tolerance<-tolerance * .01 
-        if(lastBestFitCount  %in% seq(1,100,4)) gradientIterations<-gradientIterations+1
-        if(lastBestFitCount  %in% seq(3,100,4)) gradientIterations<-gradientIterations-1
-        if(lastBestFitCount > 5) model <- omxSetParameters(model, labels = names(bestfit.params), 
-          values = bestfit.params * runif(length(bestfit.params),loc-(rnorm(1,scale,1)/10),loc+(rnorm(1,scale,1)/10)))
-      }
-      
-      
-      
-      
-      model<-mxModel(model, mxComputeSequence(list(
-        mxComputeGradientDescent(verbose=verbose, gradientStepSize = gradientStepSize, 
-          nudgeZeroStarts=FALSE,   gradientIterations = gradientIterations, tolerance=tolerance, 
-          maxMajorIter=3000),
-        mxComputeReportDeriv())))
-      
-      if(showInits==TRUE) {
-        message('Starting values:  ')
-        message(paste0(names(omxGetParameters(model)),' : ', omxGetParameters(model),'\n'))
-      }
-      
-      
-      fit <- suppressWarnings(try(mxRun(model, suppressWarnings = T, unsafe=T, silent=T,intervals=FALSE)))
-      
-      numdone <- numdone + 1
-      
-      
-      if(class(fit) == "try-error" || fit$output$status$status== -1 || is.na(fit$output$minimum)) {
-        lastBestFitCount <- 0
-        lastNoError<-FALSE
-        message('\n Fit attempt generated errors') 
-      }
-      
-      if(class(fit) != "try-error" && fit$output$status$status != -1 && !is.na(fit$output$minimum)) { #if fit was not an error
-        
-        if (fit$output$minimum >= lowestminsofar) {
-          lastBestFitCount <- 0
-          lastNoError<-TRUE
-          message('\n Fit attempt did not beat the current best') 
-        }
-        
-        if (fit$output$minimum < lowestminsofar) { #if this is the best fit so far, check the following if required
-          lastBestFitCount<-lastBestFitCount+1 
-          lowestminsofar <- fit$output$minimum
-          lastNoError<-TRUE
-          bestfit <- fit
-          bestfit.params <- omxGetParameters(bestfit)
-          
-          if (length(fit$output$calculatedHessian) == 0) {
-            checkHess <- FALSE
-          }
-          if (checkHess) {
-            if (sum(is.na(fit$output$calculatedHessian)) > 
-                0) {
-              checkHess <- FALSE
-            }
-          }
-        }
-        
-        
-        stopflag <- ifelse(checkHess, (fit$output$status[[1]] <= 
-            greenOK) & (all(eigen(fit$output$calculatedHessian, 
-              symmetric = T, only.values = T)$values > 0)) & 
-            (fit$output$minimum <= fit2beat) & (fit$output$minimum <= lowestminsofar), (fit$output$status[[1]] <=  #added lowestminsofar condition
-                greenOK) & (fit$output$minimum <= fit2beat) & (fit$output$minimum <= lowestminsofar) )
-        
-        if (!stopflag) {        
-          if(iterationSummary==TRUE){
-            message(paste0("Attempt ",numdone," fit:  "))
-            message(paste(names(params),": ", fit$output$estimate,"\n"))
-            message(paste0("-2LL = ", fit$output$Minus2LogLikelihood))
-          }
-        }
-        
-        if(stopflag){
-          message('\nSolution found\n')
-          if(length(bestfit$intervals)>0){ #only calculate confidence intervals once the best fit is established
+        if(lastBestFitCount == 0 & numdone > 0){ #if the last fit was not the best
+            if(exists('bestfit')) params<-bestfit.params #if bestfit exists use this instead
+            if(numdone %% 4 == 0) params<-inits #sometimes, use initial start values instead
             
-            message("Estimating confidence intervals\n") 
+            model <- omxSetParameters(model, labels = names(params), 
+                values = params * rnorm(length(params),loc,scale) + rnorm(length(params),0,scale)
+            )
             
-            mxOption(NULL, "Default optimizer")
-            bestfit <- OpenMx::mxModel(bestfit, 
-              mxComputeConfidenceInterval(plan=mxComputeGradientDescent(nudgeZeroStarts=FALSE, 
-                gradientIterations=gradientIterations, tolerance=tolerance, 
-                maxMajorIter=1000),
-                constraintType=ifelse(mxOption(NULL, "Default optimizer") == 'NPSOL','none','ineq')))
-            
-            cifit<-suppressWarnings(try(mxRun(bestfit,intervals=TRUE,suppressWarnings=T,silent=T)))
-            
-            
-            if(class(cifit) == "try-error" || cifit$output$status$status== -1) {
-              message('Confidence interval estimation generated errors\n')
-            } else {
-              if (length(OpenMx::summary(cifit)$npsolMessage) > 0) message('Warning messages generated from confidence interval refit\n')
-              bestfit<-cifit
+            gradientStepSize <- initialGradientStepSize
+            tolerance <- initialTolerance
+            gradientIterations<-initialGradientIterations
+        }#end if last fit not best section
+        
+        
+        if(lastBestFitCount > 0){ #if the last fit was the best so far
+            if(exists('bestfit')) {
+                params<-bestfit.params      
+                model<-bestfit
             }
             
+          if(defaultComputePlan==TRUE){
+            
+            if(lastBestFitCount == 2) gradientStepSize <- gradientStepSize *.1
+            if(lastBestFitCount == 3) gradientStepSize <- gradientStepSize *10
+            if(lastBestFitCount == 5) gradientStepSize <- gradientStepSize *.1
+            if(lastBestFitCount  > 0) tolerance<-tolerance * .001 
+            if(lastBestFitCount  > 0) gradientIterations<-gradientIterations+2
+            # if(lastBestFitCount  %in% seq(4,100,4)) gradientIterations<-gradientIterations-1
+            if(lastBestFitCount > 2) model <- omxSetParameters(model, labels = names(bestfit.params), 
+              values = bestfit.params * rnorm(length(params),loc,scale/10) + 
+                rnorm(length(params),0,scale / 10)
+            )
           }
-          if (length(OpenMx::summary(bestfit)$npsolMessage) > 0) {
-            warning(OpenMx::summary(bestfit)$npsolMessage)
-          }
-          
-          if(iterationSummary==TRUE){
-            message(paste(names(bestfit.params),": ", bestfit$output$estimate,"\n"))
-            message(paste0("-2LL = ", bestfit$output$Minus2LogLikelihood))
-          }
-          
+            
+            if(defaultComputePlan==FALSE){
+                model <- omxSetParameters(model, labels = names(bestfit.params), 
+                    values = bestfit.params * rnorm(length(bestfit.params),loc,scale/10) + 
+                        rnorm(length(params),0,scale / 10)
+                )
+            }
+        }#end if last fit was best section
+        
+        
+        
+        
+        if(defaultComputePlan==TRUE) model<-mxModel(model, mxComputeSequence(list(
+            mxComputeGradientDescent(verbose=verbose, gradientStepSize = gradientStepSize, 
+                nudgeZeroStarts=FALSE,   gradientIterations = gradientIterations, tolerance=tolerance, 
+                maxMajorIter=3000),
+            mxComputeNumericDeriv(), mxComputeStandardError(),  
+            mxComputeReportDeriv())))
+        
+        if(showInits==TRUE) {
+            message('Starting values:  ')
+            message(paste0(names(omxGetParameters(model)),' : ', omxGetParameters(model),'\n'))
+        }
+        
+        fit <- suppressWarnings(try(mxRun(model, suppressWarnings = T, unsafe=T, silent=T,intervals=FALSE)))
+        
+        numdone <- numdone + 1
+        
+        
+        if( class(fit) == "try-error" || is.na(fit$output$minimum) || fit$output$status$status== -1) {
+            lastBestFitCount <- 0
+            lastNoError<-FALSE
+            message('\n Fit attempt generated errors') 
         }
-      } #end 'if fit not an error' section
-      
-      
-      
-      
-      
-      
-      if (numdone > extraTries & stopflag==FALSE) { #added stopflag==FALSE
-        message('\nRetry limit reached')
-        stopflag <- TRUE
-        if (exists("bestfit")) {
+        
+        if(class(fit) != "try-error" & !is.na(fit$output$minimum) & fit$output$status$status != -1) { #if fit was not an error
+            
+            if (fit$output$minimum >= lowestminsofar + generalTolerance) {
+                lastBestFitCount <- 0
+                lastNoError<-TRUE
+                message(paste0('\n Fit attempt worse than current best:  ',fit$output$minimum ,' vs ', lowestminsofar )) 
+            }
           
-          if(length(bestfit$intervals)>0){ #calculate intervals for best fit, even though imperfect
-            message("Estimate confidence intervals for imperfect solution\n") 
-            #           mxOption(NULL, "Default optimizer", "NPSOL")
-            cifit<-suppressWarnings(try(mxRun(bestfit,intervals=TRUE,suppressWarnings=T,silent=T)))
-            if(class(cifit) == "try-error" || cifit$output$status$status== -1) {
-              message('Confidence interval estimation generated errors, returning fit without confidence intervals\n')
-            } else {
-              bestfit<-cifit
+          if(fit$output$minimum >= lowestminsofar) lastBestFitCount<-0
+            
+            if (fit$output$minimum < lowestminsofar) { #if this is the best fit so far
+                message(paste0('\n Lowest minimum so far:  ',fit$output$minimum) )
+                lastBestFitCount<-lastBestFitCount+1 
+                lowestminsofar <- fit$output$minimum
+                lastNoError<-TRUE
+                bestfit <- fit
+                bestfit.params <- omxGetParameters(bestfit)
+            }
+            
+            if (fit$output$minimum <= lowestminsofar + generalTolerance) { #if this is the best fit or equal best so far, check the following
+                ###########stopflag checks
+                stopflag<-TRUE
+                
+                if(fit$output$status[[1]] > greenOK) {
+                    stopflag<-FALSE
+                    message(paste0('\n OpenMx status code ', fit$output$status[[1]], ' greater than ', as.numeric(greenOK)))
+                    
+                }
+                
+                
+                if(fit$output$minimum > fit2beat) {
+                    message(paste0('\n Fit value of ', fit$output$minimum, ' greater than fit2beat of ', fit2beat))
+                    stopflag<-FALSE
+                }
+                
+                if(fit$output$minimum > lowestminsofar + generalTolerance){
+                    message(paste0('\n Fit value of ', fit$output$minimum, ' greater than best so far of ', lowestminsofar))
+                    stopflag<-FALSE
+                }
+                
+                if(checkHess==TRUE) {
+                    hessEigenval <- try(eigen(fit$output$calculatedHessian, symmetric = T, only.values = T)$values)
+                    
+                    if(class(hessEigenval)=='try-error') {
+                        message(paste0('\n Eigenvalues of hessian could not be calculated'))
+                        stopflag<-FALSE
+                    }
+                    
+                    if(class(hessEigenval)!='try-error' && any(hessEigenval < 0)) {
+                        message(paste0('\n Not all eigenvalues of hessian are greater than ', 0,': ', paste(hessEigenval,collapse=', ')))
+                        stopflag<-FALSE
+                    }
+                    
+                    #           if(stopflag==TRUE && any(hessEigenval < 0)) {
+                    # message('Some hessian eigenvalues were negative but within tolerance of ', generalTolerance, ', hessian adjusted to provide standard errors.')
+                    #             newhess<- eigen(fit$output$calculatedHessian)$vectors %*% diag(abs(hessEigenval)) %*% solve(eigen(fit$output$calculatedHessian)$vectors)
+                    #             fit@output$calculatedHessian[,]<-newhess
+                    #           }
+                    
+                    if(stopflag ==TRUE) bestfit <- fit #message(paste(hessEigenval,collapse=', '))
+                }
+                
+            }#end stopflag checks and if lowest min section
+            
+            if (!stopflag) {        
+                if(iterationSummary==TRUE){
+                    message(paste0("\n Attempt ",numdone," fit:  "))
+                    message(paste(names(params),": ", fit$output$estimate,"\n"))
+                    message(paste0("-2LL = ", fit$output$Minus2LogLikelihood))
+                }
+            }
+            
+            if(stopflag){
+                message('\nSolution found\n')
+                if(length(bestfit$intervals)>0 & intervals==TRUE){ #only calculate confidence intervals once the best fit is established
+                    
+                    message("Estimating confidence intervals\n") 
+                    
+                    if(defaultComputePlan==TRUE) bestfit <- OpenMx::mxModel(bestfit, 
+                        mxComputeSequence(list(
+                            mxComputeConfidenceInterval(plan=mxComputeGradientDescent(nudgeZeroStarts=FALSE, 
+                                gradientIterations=gradientIterations, tolerance=tolerance, 
+                                maxMajorIter=3000),
+                                constraintType=ifelse(mxOption(NULL, "Default optimizer") == 'NPSOL','none','ineq')),
+                            mxComputeNumericDeriv(), mxComputeStandardError(), 
+                            mxComputeReportDeriv())))
+                    
+                    cifit<-suppressWarnings(try(mxRun(bestfit,intervals=TRUE,suppressWarnings=T,silent=T)))
+                    
+                    
+                    if(class(cifit) == "try-error" || cifit$output$status$status== -1) {
+                        message('Confidence interval estimation generated errors\n')
+                    } else {
+                        if (length(OpenMx::summary(cifit)$npsolMessage) > 0) message('Warning messages generated from confidence interval refit\n')
+                        bestfit<-cifit
+                    }
+                    
+                }
+                if (length(OpenMx::summary(bestfit)$npsolMessage) > 0) {
+                    warning(OpenMx::summary(bestfit)$npsolMessage)
+                }
+                
+                if(iterationSummary==TRUE){
+                    message(paste(names(bestfit.params),": ", bestfit$output$estimate,"\n"))
+                    message(paste0("-2LL = ", bestfit$output$Minus2LogLikelihood))
+                }
+                
+            }
+        } #end 'if fit not an error' section
+        
+        
+        
+        
+        
+        
+        if (numdone > extraTries & stopflag==FALSE) { #added stopflag==FALSE
+            message('\nRetry limit reached')
+            stopflag <- TRUE
+            if (exists("bestfit")) {
+                
+                if(length(bestfit$intervals)>0 & intervals==TRUE){ #calculate intervals for best fit, even though imperfect
+                    message("Estimate confidence intervals for imperfect solution\n") 
+                    
+                    if(defaultComputePlan==TRUE) bestfit <- OpenMx::mxModel(bestfit, 
+                        mxComputeSequence(list(
+                            mxComputeConfidenceInterval(plan=mxComputeGradientDescent(nudgeZeroStarts=FALSE, 
+                                gradientIterations=gradientIterations, tolerance=tolerance, 
+                                maxMajorIter=3000),
+                                constraintType=ifelse(mxOption(NULL, "Default optimizer") == 'NPSOL','none','ineq')),
+                            mxComputeNumericDeriv(), mxComputeStandardError(), 
+                            mxComputeReportDeriv())))
+                    
+                    cifit<-suppressWarnings(try(mxRun(bestfit,intervals=TRUE,suppressWarnings=T,silent=T)))
+                    
+                    if(class(cifit) == "try-error" || cifit$output$status$status== -1) {
+                        message('Confidence interval estimation generated errors, returning fit without confidence intervals\n')
+                    } else {
+                        bestfit<-cifit
+                    }
+                }
+                if (length(bestfit$output$status$statusMsg) > 0) { 
+                    warning(bestfit$output$status$statusMsg)
+                }
+                if(bestfit$output$status$code==6) message('\nUncertain solution found - consider parameter validity, try again, increase extraTries, change inits, change model, or check data!\n')
+                if(iterationSummary==TRUE){
+                    message(paste(names(bestfit.params),": ", bestfit$output$estimate,"\n"))
+                    message(paste0("-2LL = ", bestfit$output$Minus2LogLikelihood))
+                }
             }
-          }
-          if (length(bestfit$output$status$statusMsg) > 0) { 
-            warning(bestfit$output$status$statusMsg)
-          }
-          if(bestfit$output$status$code==6) message('\nUncertain solution found - consider parameter validity, try again, increase extraTries, change inits, change model, or check data!\n')
-          if(iterationSummary==TRUE){
-            message(paste(names(bestfit.params),": ", bestfit$output$estimate,"\n"))
-            message(paste0("-2LL = ", bestfit$output$Minus2LogLikelihood))
-          }
         }
-      }
     } #end while loop
     
     
     
-    if(bestInitsOutput && exists("bestfit")){
-      bestfit.params <- omxGetParameters(bestfit)
-      message("\nStart values from best fit:")
-      if(paste) message(paste(bestfit.params, sep=",", collapse = ",")) 
-      if(!paste)  message(paste(names(bestfit.params),": ", bestfit.params,"\n"))
+    if(bestInitsOutput & exists("bestfit")){
+        bestfit.params <- omxGetParameters(bestfit)
+        message("\nStart values from best fit:")
+        if(paste) message(paste(bestfit.params, sep=",", collapse = ",")) 
+        if(!paste)  message(paste(names(bestfit.params),": ", bestfit.params,"\n"))
     }
     
     if (!exists("bestfit")) {
-      if(class(fit) == 'try-error') warning(fit[[length(fit)]])
-      message('All fit attempts resulted in errors - check starting values or model specification')
-      bestfit<-fit
+        if(class(fit) == 'try-error') warning(fit[[length(fit)]])
+        message('All fit attempts resulted in errors - check starting values or model specification')
+        bestfit<-fit
     }
     
     return(bestfit)
-  }
+}
