@@ -29,10 +29,10 @@
 #include "omxState.h"
 #include "omxExpectationBA81.h"  // improve encapsulation TODO
 
-omxData::omxData(omxState *state) : rownames(0), dataObject(0), dataMat(0), meansMat(0), acovMat(0), obsThresholdsMat(0),
+omxData::omxData() : rownames(0), dataObject(0), dataMat(0), meansMat(0), acovMat(0), obsThresholdsMat(0),
 		     thresholdCols(0), numObs(0), _type(0), numFactor(0), numNumeric(0),
 		     indexVector(0), identicalDefs(0), identicalMissingness(0),
-				    identicalRows(0), rows(0), cols(0), currentState(state),
+				    identicalRows(0), rows(0), cols(0),
 		     expectation(0)
 {}
 
@@ -63,7 +63,7 @@ void omxData::addDynamicDataSource(omxExpectation *ex)
 	ex->dynamicDataSource = true;
 }
 
-void omxData::connectDynamicData()
+void omxData::connectDynamicData(omxState *currentState)
 {
 	if (!dataObject) return;
 
@@ -78,8 +78,7 @@ void omxData::connectDynamicData()
 		return;
 	}
 
-	omxState *globalState = currentState;
-	omxExpectation *ex = omxExpectationFromIndex(INTEGER(dataLoc)[0], globalState);
+	omxExpectation *ex = omxExpectationFromIndex(INTEGER(dataLoc)[0], currentState);
 	if (Rf_length(dataLoc) == 1) {
 		BA81Expect *other = (BA81Expect *) ex->argStruct;
 		numObs = other->weightSum;
@@ -95,7 +94,7 @@ void omxData::connectDynamicData()
 		double weightSum = 0;
 
 		for (int sx=0; sx < num; ++sx) {
-			omxExpectation *ex = omxExpectationFromIndex(evec[sx], globalState);
+			omxExpectation *ex = omxExpectationFromIndex(evec[sx], currentState);
 			if (!strEQ(ex->expType, "MxExpectationBA81")) {
 				omxRaiseErrorf("MxDataDynamic: type='cov' is only valid for MxExpectationBA81, not '%s'",
 					       ex->expType);
@@ -121,8 +120,8 @@ void omxData::connectDynamicData()
 		if (!refE) return;
 
 		int dims = refBA81->grp.maxAbilities;
-		dataMat = omxNewIdentityMatrix(dims, globalState);
-		meansMat = omxInitMatrix(dims, 1, TRUE, globalState);
+		dataMat = omxNewIdentityMatrix(dims, currentState);
+		meansMat = omxInitMatrix(dims, 1, TRUE, currentState);
 		for (int mx=0; mx < dims; ++mx) omxSetVectorElement(meansMat, mx, 0);
 		version = 0;
 	}
@@ -142,10 +141,9 @@ void omxData::recompute()
 	}
 }
 
-void omxData::newDataStatic(SEXP dataObject)
+void omxData::newDataStatic(omxState *state, SEXP dataObject)
 {
 	omxData *od = this;
-	omxState *state = currentState;
 	SEXP dataLoc, dataVal;
 	int numCols;
 
@@ -319,7 +317,6 @@ void omxData::newDataStatic(SEXP dataObject)
 
 omxData* omxState::omxNewDataFromMxData(SEXP dataObject, const char *name)
 {
-	omxState *globalState = this;
 	if(dataObject == NULL) {
 		Rf_error("Null Data Object detected.  This is an internal Rf_error, and should be reported on the forums.\n");
 	}
@@ -330,9 +327,9 @@ omxData* omxState::omxNewDataFromMxData(SEXP dataObject, const char *name)
 		dclass = CHAR(DataClass);
 	}
 	if(OMX_DEBUG) {mxLog("Initializing %s element", dclass);}
-	omxData* od = new omxData(globalState);
+	omxData* od = new omxData();
 	dataList.push_back(od);
-	if (strcmp(dclass, "MxDataStatic")==0) od->newDataStatic(dataObject);
+	if (strcmp(dclass, "MxDataStatic")==0) od->newDataStatic(this, dataObject);
 	else if (strcmp(dclass, "MxDataDynamic")==0) newDataDynamic(dataObject, od);
 	else Rf_error("Unknown data class %s", dclass);
 	od->name = name;
@@ -385,15 +382,9 @@ omxMatrix* omxDataCovariance(omxData *od)
 	Rf_error("%s: type='cov' data must be in matrix storage", od->name);
 }
 
-omxMatrix* omxDataAcov(omxData *od) {
-	if(od->acovMat) return od->acovMat;
-
-	// Otherwise, we must construct the matrix.
-	int numRows = ( (od->rows)*(od->rows + 1) ) / 2;
-	
-	omxMatrix* om = omxInitMatrix(numRows, numRows, TRUE, od->currentState);
-	omxCopyMatrix(om, od->acovMat);
-	return om;
+omxMatrix* omxDataAcov(omxData *od)
+{
+	return od->acovMat;  // can be NULL
 }
 
 bool omxDataColumnIsFactor(omxData *od, int col)
@@ -901,10 +892,10 @@ int omxData::handleDefinitionVarList(omxState *state, int row, double* oldDefs)
 	return numVarsFilled;
 }
 
-void omxData::loadFakeData(double fake)
+void omxData::loadFakeData(omxState *state, double fake)
 {
 	for (int dx=0; dx < int(defVars.size()); ++dx) {
-		defVars[dx].loadData(currentState, fake);
+		defVars[dx].loadData(state, fake);
 	}
 }
 
@@ -916,6 +907,10 @@ void omxDefinitionVar::loadData(omxState *state, double val)
 		int matcol = cols[l];
 		omxMatrix *matrix = state->matrixList[matrixNumber];
 		omxSetMatrixElement(matrix, matrow, matcol, val);
+		if (OMX_DEBUG) {
+			mxLog("Load fake data %f into %s[%d,%d], state[%d]",
+			      val, matrix->name(), matrow, matcol, state->getId());
+		}
 	}
 	markDefVarDependencies(state, this);
 }
