@@ -107,7 +107,7 @@ void omxDuplicateFitMatrix(omxMatrix *tgt, const omxMatrix *src, omxState* newSt
 
 void omxFitFunctionComputeAuto(omxFitFunction *off, int want, FitContext *fc)
 {
-	if (want & (FF_COMPUTE_DIMS | FF_COMPUTE_INITIAL_FIT)) return;
+	if (want & (FF_COMPUTE_INITIAL_FIT)) return;
 
 	if (!off->initialized) Rf_error("FitFunction not initialized");
 
@@ -122,7 +122,7 @@ void omxFitFunctionComputeAuto(omxFitFunction *off, int want, FitContext *fc)
 
 void omxFitFunctionCompute(omxFitFunction *off, int want, FitContext *fc)
 {
-	if (want & (FF_COMPUTE_DIMS | FF_COMPUTE_INITIAL_FIT)) return;
+	if (want & (FF_COMPUTE_INITIAL_FIT)) return;
 
 	if (!off->initialized) Rf_error("FitFunction not initialized");
 
@@ -132,7 +132,7 @@ void omxFitFunctionCompute(omxFitFunction *off, int want, FitContext *fc)
 
 void omxFitFunctionComputeCI(omxFitFunction *off, int want, FitContext *fc)
 {
-	if (want & (FF_COMPUTE_DIMS | FF_COMPUTE_INITIAL_FIT)) return;
+	if (want & (FF_COMPUTE_INITIAL_FIT)) return;
 
 	if (!off->initialized) Rf_error("FitFunction not initialized");
 
