@@ -44,9 +44,9 @@ void omxInitGREMLExpectation(omxExpectation* ox){
   
     /* Set up expectation structures */
   //y:
-  oge->y = new omxData(currentState);
+  oge->y = new omxData();
   {ScopedProtect p1(Rmtx, R_do_slot(rObj, Rf_install("y")));
-  oge->y->newDataStatic(Rmtx);
+	  oge->y->newDataStatic(currentState, Rmtx);
   }
   //V:
 	if(OMX_DEBUG) { mxLog("Processing V."); }
@@ -195,7 +195,8 @@ void omxComputeGREMLExpectation(omxExpectation* ox, const char *, const char *)
   fitfunction.  If its false, that means that the GREML fitfunction is being used, and it knows how to handle
   a "half-full" Vinv.*/
   else{
-  	Vinv = ( cholV.solve(Eigen::MatrixXd::Identity( EigV.rows(), EigV.cols() )) ).triangularView<Eigen::Lower>(); //<-- V inverse
+  	//V inverse:
+  	Vinv.triangularView<Eigen::Lower>() = ( cholV.solve(Eigen::MatrixXd::Identity( EigV.rows(), EigV.cols() )) ).triangularView<Eigen::Lower>();
   	oge->XtVinv = EigX.transpose() * Vinv.selfadjointView<Eigen::Lower>();
   }
   quadX.triangularView<Eigen::Lower>() = oge->XtVinv * EigX;
