@@ -269,10 +269,13 @@ extern struct omxGlobal *Global;
 class omxState {
  private:
 	void init();
+	static int nextId;
+	int stateId;
 	int wantStage;
  public:
 	int getWantStage() const { return wantStage; }
 	void setWantStage(int stage);
+	int getId() const { return stateId; }
 
 	std::vector< omxMatrix* > matrixList;
 	std::vector< omxMatrix* > algebraList;
@@ -282,8 +285,6 @@ class omxState {
 	// not copied to sub-states
 	std::vector< omxConstraint* > conList;
 
-	long int currentRow; // only used for debugging
-
 	omxState() { init(); };
 	omxState(omxState *src);
 	void omxProcessMxMatrixEntities(SEXP matList);
@@ -323,8 +324,6 @@ inline bool isErrorRaised() { return Global->bads.size() != 0; }
 void omxRaiseError(const char* Rf_errorMsg); // DEPRECATED
 void omxRaiseErrorf(const char* Rf_errorMsg, ...) __attribute__((format (printf, 1, 2)));
 
-void omxStateNextRow(omxState *state);
-
 std::string string_vsnprintf(const char *fmt, va_list ap);
 
 #endif /* _OMXSTATE_H_ */
